==> desktopcouch_1.0.7.orig.tar.gz: desktopcouch-1.0.7/desktopcouch/application/tests/test_service.py <==
"""Test the desktopcouch service."""

import logging
import signal

from mocker import MockerTestCase, ANY

from desktopcouch.application.service import (
    DesktopcouchService)

logging.basicConfig(level=logging.ERROR)


def set_up_logging(_):
    """ Set logging to be silence."""
    logging.basicConfig(level=logging.ERROR)


class TestService(MockerTestCase):
    """Test the class that manages the service."""

    def setUp(self):
        super(TestService, self).setUp()
        # set up the dependencies used by the service object
        self._pid_result = 32
        self._port_result = 32323
        self._mainloop = self.mocker.mock()
        self._pid_finder = self.mocker.mock()
        self._port_finder = self.mocker.replace(
            'desktopcouch.application.platform.find_port', passthrough=False)
        self._ctx = self.mocker.mock()
        self._stop_couchdb = self.mocker.mock()
        self._fork = self.mocker.mock()
        self._nice = self.mocker.mock()
        self._kill = self.mocker.mock()
        self._sleep = self.mocker.mock()
        self._replication = self.mocker.mock()
        self._advertiser = self.mocker.mock()
        self._resources = self.mocker.mock()
        self._service = DesktopcouchService(self._mainloop,
            pid_finder=self._pid_finder,
            port_finder=self._port_finder,
            ctx=self._ctx,
            stop_couchdb=self._stop_couchdb,
            replication_actions=self._replication,
            advertiser_factory=self._advertiser,
            set_logging=set_up_logging,
            fork=self._fork,
            nice=self._nice,
            kill=self._kill,
            sleep=self._sleep)

    def test_start_new_desktopcouch_no_extensions(self):
        """Test that desktopcouch is started.

        We test that when the pid cannot be found we ensure
        that the desktopcouch instance is started and that the
        start as the dbus service,
        """
        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(None)
        self._pid_finder(start_if_not_running=True, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(234)
        self._fork()
        self.mocker.result(234)
        # XXX: call this?
        self._mainloop.stop             # pylint: disable=W0104
        self.mocker.result(ANY)
        self._advertiser(ANY, self._ctx)
        self._mainloop.run()
        self._stop_couchdb(ctx=self._ctx)
        self._kill(234, signal.SIGTERM)
        self._sleep(1)
        self._kill(234, signal.SIGKILL)
        self.mocker.replay()
        self._service.start()

    def test_start_new_desktopcouch_extensions(self):
        """Test that desktopcouch is started.

        We test that when the pid cannot be found we ensure
        that the desktopcouch instance is started and that the
        start as the dbus service,
        """
        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(None)
        self._pid_finder(start_if_not_running=True, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(234)
        self._fork()
        self.mocker.result(234)
        # XXX: call this?
        self._mainloop.stop             # pylint: disable=W0104
        self.mocker.result(ANY)
        self._advertiser(ANY, self._ctx)
        self._mainloop.run()
        self._stop_couchdb(ctx=self._ctx)
        self._kill(234, signal.SIGTERM)
        self._sleep(1)
        self._kill(234, signal.SIGKILL)
        self.mocker.replay()
        self._service.start()

    def test_start_desktopcouch_replication(self):
        """ Test that the repliciation works.

        We test that when desktopcouch is already running we
        will not start it again and we will perform the replication.
        """
        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(0)
        self._nice(10)
        self._replication.set_up(ANY)
        self._mainloop.run()
        self.mocker.replay()
        self._service.start()

    def test_start_migrate_data(self):
        """Test that desktopcouch is started.

        We test that when the pid cannot be found we ensure
        that the desktopcouch instance is started and that the
        start as the dbus service,
        """

        server_class = self.mocker.replace("desktopcouch.application." +
                "server.DesktopServer", passthrough=False)
        database_class = self.mocker.replace("desktopcouch.application." +
                "server.DesktopDatabase", passthrough=False)

        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(None)
        self._pid_finder(start_if_not_running=True, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(567)
        self._fork()
        self.mocker.result(0)
        self._sleep(ANY)
        self._ctx.db_dir  # searching for files    # pylint: disable=W0104
        self.mocker.result("/tmp/migration-data/does/not/exist")

        self._port_finder(ctx=self._ctx)     # pylint: disable=W0104
        self.mocker.result(self._port_result)

        server_class('http://localhost:' + str(self._port_result),
                     ctx=self._ctx, oauth_tokens=None)
        self.mocker.result(["fakedb1"])

        d = database_class(database='fakedb1', ctx=self._ctx)
        d.add_view('migrate_deleted', design_doc='dc_migration', map_js=ANY)
        view = self.mocker.mock()
        d.execute_view              # pylint: disable=W0104
        self.mocker.result(view)
        view(design_doc='dc_migration',
             view_name='migrate_deleted')  # pylint: disable=W0104
        record = self.mocker.mock()
        self.mocker.result([record])
        record.id              # pylint: disable=W0104
        self.mocker.result("rid")
        d.delete_record("rid")    # pylint: disable=W0104

        self.mocker.replay()
        self._service.start()

==> desktopcouch_1.0.8.orig.tar.gz: desktopcouch-1.0.8/desktopcouch/application/tests/test_service.py <==
"""Test the desktopcouch service."""

import logging
import signal

from mocker import MockerTestCase, ANY

from desktopcouch.application.service import (
    DesktopcouchService)

logging.basicConfig(level=logging.ERROR)


def set_up_logging(_):
    """ Set logging to be silence."""
    logging.basicConfig(level=logging.ERROR)


class TestService(MockerTestCase):
    """Test the class that manages the service."""

    def setUp(self):
        super(TestService, self).setUp()
        # set up the dependencies used by the service object
        self._pid_result = 32
        self._port_result = 32323
        self._mainloop = self.mocker.mock()
        self._pid_finder = self.mocker.mock()
        self._port_finder = self.mocker.replace(
            'desktopcouch.application.platform.find_port', passthrough=False)
        self._ctx = self.mocker.mock()
        self._stop_couchdb = self.mocker.mock()
        self._fork = self.mocker.mock()
        self._nice = self.mocker.mock()
        self._kill = self.mocker.mock()
        self._sleep = self.mocker.mock()
        self._replication = self.mocker.mock()
        self._advertiser = self.mocker.mock()
        self._resources = self.mocker.mock()
        self._set = self.mocker.mock()
        self._gobject = self.mocker.mock()
        self._service = DesktopcouchService(self._mainloop,
            pid_finder=self._pid_finder,
            port_finder=self._port_finder,
            ctx=self._ctx,
            stop_couchdb=self._stop_couchdb,
            replication_actions=self._replication,
            advertiser_factory=self._advertiser,
            set_logging=set_up_logging,
            fork=self._fork,
            nice=self._nice,
            kill=self._kill,
            sleep=self._sleep,
            set_type=self._set,
            gobject_module=self._gobject)

        self.gobject_idle_task_list = list()

    def test_start_new_desktopcouch_with_plugins(self):
        """Test that desktopcouch is started.

        We test that when the pid cannot be found we ensure
        that the desktopcouch instance is started and that the
        start as the dbus service,
        """
        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(None)
        self._pid_finder(start_if_not_running=True, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(234)  # We are parent
        self._fork()
        self.mocker.result(345)  # We are parent

        # plugins load
        semaphores = self.mocker.mock()
        self._set()
        self.mocker.result(semaphores)

        self._mainloop.stop             # pylint: disable=W0104
        self.mocker.result(ANY)

        semaphores.discard              # pylint: disable=W0104
        self.mocker.result("disc")
        self._gobject.timeout_add_seconds(ANY, "disc", ANY)

        self._gobject.idle_add(ANY, self._port_result, semaphores)
        self._gobject.idle_add(ANY, semaphores, self._advertiser, ANY,
                               self._ctx)

        self._mainloop.run()

        # Tasks are added to the mainloop's idle queue.  With that^
        # mainloop.run, they'd be called.  Simulate their call.

        # Idle loop to add plugins calls a plugin.  ubuntuone_pairing
        semaphores.add(ANY)  # A plugin asserts it must be completed.

        # Idle loop calls plugin for ubuntuone_pairing, which fires up DBus
        # client to get credentials from ubuntu-login app.  When that returns,
        # it calls got_new_credentials, which calls pair_with_ubuntuone.

        # Mock call to pair_with_ubuntuone
        management_db = self.mocker.mock()
        put_service_fn = self.mocker.mock()

        bool(management_db)
        self.mocker.result(True)

        management_db.view_exists(ANY, ANY)
        self.mocker.result(False)
        management_db.add_view(ANY, ANY, design_doc=ANY)

        row = self.mocker.mock()
        management_db.execute_view(ANY, ANY)
        self.mocker.result([row])

        row.value               # pylint: disable=W0104
        self.mocker.result(1)

        semaphores.discard(ANY)

        # and then dbus service is ready to answer queries.

        self._stop_couchdb(ctx=self._ctx)
        self._kill(self._pid_result, signal.SIGTERM)
        self._kill(234, signal.SIGTERM)
        self._kill(345, signal.SIGTERM)
        self._sleep(1)
        self._kill(self._pid_result, signal.SIGKILL)
        self._kill(234, signal.SIGKILL)
        self._kill(345, signal.SIGKILL)

        self.mocker.replay()

        self._service.start()
        # Manually do what dbus idle-loop would do.
        import desktopcouch.application.plugins.ubuntuone_pairing as u_p
        u_p.pair_with_ubuntuone(self._port_result, semaphores,
                management_db=management_db,
                put_service_fn=put_service_fn)

    def test_start_desktopcouch_replication(self):
        """ Test that the repliciation works.

        We test that when desktopcouch is already running we
        will not start it again and we will perform the replication.
        """
        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(0)  # We are child process
        self._nice(10)
        self._replication.set_up(ANY)
        self._mainloop.run()
        self.mocker.replay()
        self._service.start()

    def test_start_migrate_data(self):
        """Test that desktopcouch is started.

        We test that when the pid cannot be found we ensure
        that the desktopcouch instance is started and that the
        start as the dbus service,
        """

        server_class = self.mocker.replace("desktopcouch.application." +
                "server.DesktopServer", passthrough=False)
        database_class = self.mocker.replace("desktopcouch.application." +
                "server.DesktopDatabase", passthrough=False)

        self._pid_finder(start_if_not_running=False, ctx=self._ctx)
        self.mocker.result(None)
        self._pid_finder(start_if_not_running=True, ctx=self._ctx)
        self.mocker.result(self._pid_result)
        self._port_finder(pid=self._pid_result, ctx=self._ctx)
        self.mocker.result(self._port_result)
        self._fork()
        self.mocker.result(567)  # We are parent process
        self._fork()
        self.mocker.result(0)  # We are child process
        self._sleep(ANY)
        self._ctx.db_dir  # searching for files    # pylint: disable=W0104
        self.mocker.result("/tmp/migration-data/does/not/exist")

        self._port_finder(ctx=self._ctx)     # pylint: disable=W0104
        self.mocker.result(self._port_result)

        server_class('http://localhost:' + str(self._port_result),
                     ctx=self._ctx, oauth_tokens=None)
        self.mocker.result(["fakedb1"])

        d = database_class(database='fakedb1', ctx=self._ctx)
        d.add_view('migrate_deleted', design_doc='dc_migration', map_js=ANY)
        view = self.mocker.mock()
        d.execute_view              # pylint: disable=W0104
        self.mocker.result(view)
        view(design_doc='dc_migration',
             view_name='migrate_deleted')  # pylint: disable=W0104
        record = self.mocker.mock()
        self.mocker.result([record])
        record.id              # pylint: disable=W0104
        self.mocker.result("rid")
        d.delete_record("rid")    # pylint: disable=W0104

        self.mocker.replay()
        self._service.start()
